==> haskell-interpolate-0.2.1-429-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-5Mltld6t6VpDGkn1pDKAgP
key:                  interpolate-0.2.1-5Mltld6t6VpDGkn1pDKAgP
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  cb41042a86f1371ef73d30887bb9aef3
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-5Mltld6t6VpDGkn1pDKAgP
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-3bugYCWjwkO8ZMaQXqxhN3
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolate-0.2.1-430-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolate
version:              0.2.1
visibility:           public
id:                   interpolate-0.2.1-ALPL1Ki1KoIGnMm1iRiJaC
key:                  interpolate-0.2.1-ALPL1Ki1KoIGnMm1iRiJaC
license:              MIT
copyright:            (c) 2013-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://github.com/sol/interpolate#readme
synopsis:             String interpolation done right
description:          String interpolation done right
category:             Data, Text
abi:                  557ef39606e571eb35566ef882f6b109
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.IsString
    Data.String.Interpolate.Util

hidden-modules:
    Data.String.Interpolate.Compat
    Data.String.Interpolate.Internal.Util Data.String.Interpolate.Parse
    Paths_interpolate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/interpolate-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolate
hs-libraries:         HSinterpolate-0.2.1-ALPL1Ki1KoIGnMm1iRiJaC
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-FbGWOaGyzY25gdCVvkFBj4
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-interpolate/html/interpolate.haddock
haddock-html:         /usr/share/doc/haskell-interpolate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
